{% extends "newsletter/signup_form_base.html" %}
{% load i18n %}

{% block newsletter_form_before %}
<div class="content-plugin newsletter-plugin">
{% endblock newsletter_form_before %}

{% block newsletter_form_after %}
</div>
{% endblock newsletter_form_after %}
