<div class="teaser teaser--tile">

    <a href="{{ teaser_link }}" class="teaser__tile-link" {% if instance.softpage_enabled %}data-softpage{% endif %}>
        {% include 'allink_teaser/includes/_image.html' with teaser_image=teaser_image %}
        {% include 'allink_teaser/includes/_technical-title.html' with teaser_technical_title=teaser_technical_title %}
        {% include 'allink_teaser/includes/_title.html' with teaser_title=teaser_title %}
        {% include 'allink_teaser/includes/_description.html' with teaser_description=teaser_description %}
        {% if instance.softpage_enabled %}
            {% include 'allink_teaser/tile/_link.html' with teaser_link=teaser_link teaser_link_text=teaser_link_text icon="softpage" %}
        {% else %}
            {% include 'allink_teaser/tile/_link.html' with teaser_link=teaser_link teaser_link_text=teaser_link_text %}
        {% endif %}
    </a>

</div>
