{% load allink_image_tags %}

<div class="teaser teaser--parallax inverted-colors">

    <div class="teaser__image">
        {% render_image width_alias="parallax" image=teaser_image alt_text=teaser_title vh_enabled=False subject_location=True %}
    </div>

    <div class="teaser__content">
        {% include 'allink_teaser/includes/_technical-title.html' with teaser_technical_title=teaser_technical_title %}
        {% include 'allink_teaser/includes/_title.html' with teaser_title=teaser_title %}
        {% include 'allink_teaser/includes/_description.html' with teaser_description=teaser_description %}
        {% include 'allink_teaser/includes/_link.html' with teaser_link=teaser_link teaser_link_text=teaser_link_text %}
    </div>

</div>
