{% extends "app_content/app_content.html" %}

{% load cms_tags staticfiles sekizai_tags i18n thumbnail %}

{# We don't want the category navigation when the single template is chosen. This makes sure it's removed. #}
{% block app_content_category_container %}
{% endblock app_content_category_container %}

{# We don't want the 'load more' button when the single is activated #}
{% block app_content_load_more_container %}
{% endblock app_content_load_more_container %}

{% block app_content_objects_container %}

    <div class="list-container ajax-items-container variation--default">
        {% include "testimonials/plugins/list/_items.html" %}
    </div>

{% endblock app_content_objects_container %}
