{% load cms_tags allink_cms_tags sekizai_tags i18n thumbnail allink_image_tags cache %}

{% for object in object_list %}
    <div class="list-item {% if appended %}appended{% endif %}">
        <div class="testimonials__col-container">
            <div class="testimonials__col testimonials__col-1">
                {% if object.lead %}
                    <div class="testimonials__lead">
                        {{object.lead}}
                    </div>
                {% endif %}
            </div>
            <div class="testimonials__col testimonials__col-2">
                {% if object.preview_image %}
                    <div class="testimonials__image">
                        {% render_image image=object.preview_image ratio="1-1" zoom="50" bg_enabled=False subject_location=True %}
                    </div>
                {% endif %}
                <div class="testimonials__text-container">
                    {% if object.title %}
                        <h3 class="testimonials__heading">
                            {% render_model_ajax object "title" %}
                        </h3>
                    {% endif %}
                    {% if object.job_function %}
                        <div class="testimonials__function">
                            <p>{% render_model_ajax object "job_function" %}</p>
                            <p>{% render_model_ajax object "company_name" %}</p>
                        </div>
                    {% endif %}
                </div>
            </div>
        </div>
    </div>
{% endfor %}
