{% extends "admin/change_form.html" %}
{% load i18n %}
{% load admin_urls %}

{% block object-tools-items %}
    {% if original.is_publishable %}
        <li><a href="{% url opts|admin_urlname:'publish' original.pk %}">{% trans "Publish" %}</a></li>
    {% endif %}
    {{ block.super }}
{% endblock %}
